<?php
/**
 * Block one
 *
 * @package    Featured
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2017, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Featured_Block_One_Builder extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'featured_block_one',
			'description' => esc_html__( 'Block one', 'featured' )
		);

		// Create the widget.
		parent::__construct(
			'featured-block-one',                  // $this->id_base
			esc_html__( 'Block One', 'featured' ), // $this->name
			$widget_options                        // $this->widget_options
		);

		$this->alt_option_name = 'featured_block_one';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Posts widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Latest News', 'featured' );
		$query = ( ! empty( $instance['query'] ) ) ? $instance['query'] : 'recent';
		// $num   = ( ! empty( $instance['number'] ) ) ? intval( $instance['number'] ) : 6;
		// if ( ! $num ) {
		// 	$num = 6;
		// }

		// Output the theme's $before_widget wrapper.
		echo $args['before_widget'];

			// If the title not empty, display it.
			if ( $instance['title'] ) {
				echo '<div class="widget-title builder-title"><span>' . $instance['title'] . '</span></div>';
			}

			// Posts query arguments.
			$query_args = array(
				'posts_per_page' => 3,
				'post_type'      => 'post',
			);

			if ( $query == 'like' ) {
				$query_args['meta_key'] = '_featured_likes';
				$query_args['orderby']  = 'meta_value_num';
			} elseif ( $query == 'popular' ) {
				$query_args['orderby']  = 'comment_count';
			} elseif ( $query == 'views' ) {
				$query_args['meta_key'] = 'Views';
				$query_args['orderby']  = 'meta_value_num';
			} elseif ( $query == 'random' ) {
				$query_args['orderby']  = 'rand';
			} else {
				$query_args['orderby']  = 'date';
			}

			// The post query
			$blockone = new WP_Query( $query_args );

			if ( $blockone->have_posts() ) : ?>

				<div class="block-one featured-builder">

					<?php while ( $blockone->have_posts() ) : $blockone->the_post(); ?>

						<?php if ( 0 === $blockone->current_post ) : ?>

							<div class="block-one-left">

								<article id="post-<?php the_ID(); ?>" <?php post_class( 'block-one-big' ); ?>>

									<div class="post-thumbnail thumbnail block-one-thumbnail">
										<?php if ( has_post_thumbnail() ) : ?>
											<a class="thumbnail-link" href="<?php the_permalink(); ?>">
												<?php the_post_thumbnail( 'block-one-big-thumbnail', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
												<span class="overlay"></span>
											</a>
										<?php endif; ?>

										<?php
											$category = get_the_category( get_the_ID() );
											if ( $category ) :
										?>
											<span class="cat-links">
												<a href="<?php echo esc_url( get_category_link( $category[0]->term_id ) ); ?>"><?php echo esc_attr( $category[0]->name ); ?></a>
											</span>
										<?php endif; // End if category ?>

									</div>

									<div class="block-one-content">

										<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

										<div class="entry-summary">
											<?php echo wp_trim_words( get_the_excerpt(), 14 ); ?>
										</div>

									</div>

									<div class="block-meta entry-meta">
										<?php featured_block_meta(); ?>
									</div>

								</article>

							</div>

						<?php else : ?>

							<?php if ( 1 === $blockone->current_post ) :?>
								<div class="block-one-right">
							<?php endif; ?>

								<article id="post-<?php the_ID(); ?>" <?php post_class( 'archive block-one-small post-with-highlight' ); ?>>

									<div class="post-thumbnail thumbnail block-one-thumbnail">
										<?php if ( has_post_thumbnail() ) : ?>
											<a class="thumbnail-link" href="<?php the_permalink(); ?>">
												<?php the_post_thumbnail( 'block-one-big-small', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
											</a>
										<?php endif; ?>

										<?php
											$category = get_the_category( get_the_ID() );
											if ( $category ) :
										?>
											<span class="cat-links">
												<a href="<?php echo esc_url( get_category_link( $category[0]->term_id ) ); ?>"><?php echo esc_attr( $category[0]->name ); ?></a>
											</span>
										<?php endif; // End if category ?>
									</div>

									<div class="post-detail block-one-content">

										<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

										<span class="entry-author vcard">
											<?php printf( esc_html__( 'by %s', 'featured' ), '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>' ); ?>
										</span>

										<div class="block-meta entry-meta">
											<?php featured_block_meta(); ?>
										</div>

									</div>

								</article><!-- #post-## -->

							<?php if ( $blockone->post_count === $blockone->current_post + 1 ) : ?>
								</div>
							<?php endif; ?>

						<?php endif; ?>

					<?php endwhile; ?>

				</div>

			<?php endif; wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $args['after_widget'];

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance           = $old_instance;
		$instance['title']  = sanitize_text_field( $new_instance['title'] );
		$instance['query']  = esc_attr( $new_instance['query'] );
		// $instance['number'] = (int) $new_instance['number'];
		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : esc_html__( 'Latest News', 'featured' );
		$query = isset( $instance['query'] ) ? esc_attr( $instance['query'] ) : 'recent';
		// $num   = isset( $instance['number'] ) ? absint( $instance['number'] ) : 6;
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'featured' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'query' ); ?>"><?php esc_html_e( 'Choose Query:', 'featured' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'query' ); ?>" name="<?php echo $this->get_field_name( 'query' ); ?>">
				<option value="recent" <?php selected( $query, 'recent' ); ?>><?php esc_html_e( 'Latest Posts', 'featured' ) ?></option>
				<option value="popular" <?php selected( $query, 'popular' ); ?>><?php esc_html_e( 'Popular Posts', 'featured' ) ?></option>
				<option value="like" <?php selected( $query, 'like' ); ?>><?php esc_html_e( 'Most Like Posts', 'featured' ) ?></option>
				<option value="views" <?php selected( $query, 'views' ); ?>><?php esc_html_e( 'Most Views Posts', 'featured' ) ?></option>
				<option value="random" <?php selected( $query, 'random' ); ?>><?php esc_html_e( 'Random Posts', 'featured' ) ?></option>
			</select>
		</p>

	<?php

	}

}
