<?php
/**
 * Modified from ZillaLikes
 * http://www.themezilla.com/plugins/zillalikes/
 *
 * @package    Featured
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2017, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * add post meta '_featured_likes'
 */
function featured_setup_likes( $post_id ) {
	if ( ! is_numeric( $post_id ) ) return;

	add_post_meta( $post_id, '_featured_likes', '0', true );
}
add_action( 'publish_post', 'featured_setup_likes' );

/**
 * AJAX callback, to get the refreshed like count
 */
function featured_ajax_callback( $post_id ) {

	if( isset( $_POST['likes_id'] ) ) {
		// Click event. Get and Update Count
		$post_id = str_replace( 'featured-likes-', '', $_POST['likes_id'] );
		echo featured_like_this( $post_id, 'update' );
	} else {
		// AJAXing data in. Get Count
		$post_id = str_replace( 'featured-likes-', '', $_POST['post_id'] );
		echo featured_like_this( $post_id, 'get' );
	}

	exit;
}
add_action( 'wp_ajax_featured-likes', 'featured_ajax_callback' );
add_action( 'wp_ajax_nopriv_featured-likes', 'featured_ajax_callback' );

/**
 * get the like count
 */
function featured_like_this( $post_id, $action = 'get' ) {

	if( ! is_numeric( $post_id ) ) return;

	switch( $action ) {

		case 'get':
			$likes = get_post_meta( $post_id, '_featured_likes', true );
			if( ! $likes ){
				$likes = 0;
				add_post_meta( $post_id, '_featured_likes', $likes, true );
			}

			return '<i class="fa fa-heart-o" aria-hidden="true"></i>' . esc_html( $likes );
		break;

		case 'update':
			$likes = get_post_meta( $post_id, '_featured_likes', true );
			if( isset( $_COOKIE['featured_likes_'. $post_id] ) ) return $likes;

			$likes++;
			update_post_meta( $post_id, '_featured_likes', $likes );
			setcookie( 'featured_likes_'. $post_id, $post_id, time()*20, '/' );

			return '<i class="fa fa-heart-o" aria-hidden="true"></i>' . esc_html( $likes );
		break;

	}
}

/**
 * Template Tag for Like counter
 */
function featured_do_likes() {

	// get the like count
	$output = featured_like_this( get_the_ID() );

	$class = 'entry-like';
	$active_class = 'none';
	$title = esc_html__( 'Like this', 'featured' );

	// check cookie, if user already like
	if( isset( $_COOKIE['featured_likes_'. get_the_ID()] ) ) {
		$active_class = 'active';
		$title = esc_html__( 'You already like this', 'featured' );
	}

	return '<span class="' . esc_attr( $class ) .'"><a href="#" class="' . esc_attr( $active_class ) . ' btn btn-more" id="featured-likes-'. get_the_ID() .'" title="'. esc_attr( $title ) . '">' . $output . '</a></span>';
}
